@@ -22,10 +22,10 @@ with Path(__file__).parent.parent.joinpath("config.yaml").resolve().open("r") as
     __DEFAULT_CONFIG: dict = yaml.safe_load(fin)
 
 
-def set_default_config(ip: str, port: int, log_directory: str, console_display_log: bool):
+def set_default_config(ip: str, port: int, log_directory: str, console_display_log: bool, system_setting: dict):
     global __DEFAULT_CONFIG
     __DEFAULT_CONFIG.update(dict(ip=ip, port=port, log_directory=log_directory,
-                                 console_display_log=console_display_log))
+                                 console_display_log=console_display_log, system_setting=system_setting))
 
 
 def get_default_config():
