@@ -21,6 +21,7 @@ import collections
 from types import SimpleNamespace
 
 from pipeline.param.base_param import BaseParam
+from pipeline.param.callback_param import CallbackParam
 from pipeline.param.cross_validation_param import CrossValidationParam
 from pipeline.param.encrypt_param import EncryptParam
 from pipeline.param.encrypted_mode_calculation_param import EncryptedModeCalculatorParam
@@ -113,7 +114,8 @@ class HeteroNNParam(BaseParam):
                  use_first_metric_only=True,
                  selector_param=SelectorParam(),
                  floating_point_precision=23,
-                 drop_out_keep_rate=1.0):
+                 drop_out_keep_rate=1.0,
+                 callback_param=CallbackParam()):
         super(HeteroNNParam, self).__init__()
 
         self.task_type = task_type
@@ -143,6 +145,8 @@ class HeteroNNParam(BaseParam):
 
         self.drop_out_keep_rate = drop_out_keep_rate
 
+        self.callback_param = copy.deepcopy(callback_param)
+
     def check(self):
         self.optimizer = self._parse_optimizer(self.optimizer)
         supported_config_type = ["keras"]
@@ -230,5 +234,7 @@ class HeteroNNParam(BaseParam):
                 raise ValueError(f"optimizer config: {opt} invalid")
             kwargs = {k: v for k, v in opt.items() if k != "optimizer"}
             return SimpleNamespace(optimizer=optimizer, kwargs=kwargs)
+        elif opt is None:
+            return None
         else:
             raise ValueError(f"invalid type for optimize: {type(opt)}")
